@@ -357,7 +357,7 @@ class WCChooseSeed(WizardComponent):
         self._valid = True
 
     def apply(self):
-        self.wizard_data['keystore_type'] = self.choice_w.selected_item[0]
+        self.wizard_data['keystore_type'] = self.choice_w.selected_key
 
 
 class WCTerms(WizardComponent):
@@ -527,9 +527,14 @@ class WCShowConfirmOTP(WizardComponent):
     def on_otp_edited(self):
         self.otp_status_l.setVisible(False)
         text = self.otp_e.text()
+        if len(text) > 0:
+            try:
+                otp_int = int(text)
+            except ValueError:
+                return
         if len(text) == 6:
             # verify otp
-            self.wizard.trustedcoin_qhelper.checkOtp(self.wizard.trustedcoin_qhelper.shortId, int(text))
+            self.wizard.trustedcoin_qhelper.checkOtp(self.wizard.trustedcoin_qhelper.shortId, otp_int)
             self.setEnabled(False)
             self.spinner_l.setVisible(True)
             self.spinner.start()
@@ -559,7 +564,7 @@ class WCKeepDisable(WizardComponent):
         self._valid = True
 
     def apply(self):
-        self.wizard_data['trustedcoin_keepordisable'] = self.choice_w.selected_item[0]
+        self.wizard_data['trustedcoin_keepordisable'] = self.choice_w.selected_key
 
 
 class WCContinueOnline(WizardComponent):
